Groups
======

.. automodule:: ls.joyous.models.groups

.. autofunction:: get_group_model_string
.. autofunction:: get_group_model

.. automodule:: ls.joyous.models

GroupPage
---------
.. inheritance-diagram:: GroupPage
    :top-classes: wagtail.core.models.Page
    :parts: 1
.. autoclass:: GroupPage
    :show-inheritance:

    .. attribute:: content

    An area of text for whatever you like


